# fe-supervisor (前端监控)

## Quick Start

Several options to get up and running:

* Clone the repo: `git clone https://github.com/BobbyLH/fe-supervisor`
* Install with [npm](https://www.npmjs.com/package/roarjs): `npm install fe-supervisor`
* Install with [Yarn](https://yarnpkg.com/en/package/roarjs): `yarn add fe-supervisor`


## foot 切换地区说明

- 将地区切换至日本时，默认为日文
- 将地区切换至除日本外的地区时， 默认为英语


## TIPS

**countries数据客户端获取更新策略**

- 使用localstorage存储，使用服务端下发的key
- 服务端统一下发key,当key
- 客户端使用api.himalaya.com请求countries 会根据地区来过滤掉中国，web站不需要这规则，顾获取countries api用node服务提供避免该过滤：`/api/countries`

### 全局通用ajax调用方式
```javascript
  import { Request } from './hocs'
  import { yourApi } from './apis'

  const YourComponent = props => {
    return <button 
      onClick={() => {
        /** 
         * httpRequest 调用方式
         * @param api 用于请求的api, 按照apis文件的规范书写
         * @param params (可选)api需要的携带参数
         * @param callbacks (可选)回调函数, 有success、fail、error、login等
         * @param {callbacks} success api请求成功，并且返回ret: 0或者success: true 的field
         * @param {callbacks} fail api请求成功，但返回的ret: 0 || -1，或者success: false 的field
         * @param {callbacks} error api请求失败，或者api请求成功但是ret: -1
         * @param {callbacks} login api请求成功，但是ret: 50，此时默认行为是重新reload[localtion.reload(true)]页面(注意：login不支持链式调用的写法，仅支持传入callbacks:{login: res => console.log(res.ret)})
        */

        // 方式1
        props.httpRequest({
          api: paymentApi.makeSubsciption,
          params: yourApiDemandParams
        }).success(res => {
          console.log('success res is: ', res)
        }).fail(res => {
          console.log('failed res is: ', res)
        }).error(err => {
          console.error('error msg is: ', err)
        })

        // 方式2 回调函数
        props.httpRequest({
          api: paymentApi.makeSubsciption,
          params: yourApiDemandParams,
          callbacks: {
            success: res => console.log('success res is: ', res),
            fail: res => console.log('failed res is: ', res),
            error: err => console.error('error msg is: ', err)
          }
        })

        // 方式3 链式调用
        // then - success或者fail触发后return的值进行链式调用
        // catch - error触发后return的值进行链式调用
        props.httpRequest({
          api: paymentApi.makeSubsciption,
          params: yourApiDemandParams
        }).success(res => {
          console.log('success res is: ', res)
          return res // 该值会传递到then中
        }).fail(res => {
          console.log('failed res is: ', res)
          return res // 该值会传递到then中
        }).error(err => {
          console.error('error msg is: ', err)
          return err // 该值会传递到catch中
        }).then(res => {
          // do something
        }).catch(err => {
          // do something with error status
        })

        // 方式4 回调+链式
        // then - success或者fail触发后return的值进行链式调用
        // catch - error触发后return的值进行链式调用
        // 注意: 传入回调函数后, 相应的链式方法不生效, 但是then和catch依然生效
        props.httpRequest({
          api: paymentApi.makeSubsciption,
          params: yourApiDemandParams,
          callbacks: {
            success: res => {
              console.log('success res is: ', res)
              return res
            },
            fail: res => {
              console.log('failed res is: ', res)
              return res
            },
            error: err => {
              console.error('error msg is: ', err)
              return err
            }
          }
        }).then(res => {
          // do something
        }).catch(err => {
          // do something with error status
        })

        // 方式5 async
        async function request () {
          const res = await props.httpRequest({
            api: paymentApi.makeSubsciption,
            params: yourApiDemandParams
          })
          console.log('res is: ', res)
        }
      }}
    >
      click me
    </button>
  }

  export default Request(YourComponent)
```
